@@ -6,11 +6,12 @@ from loguru import logger
 
 import ofanalysis.const as const
 import ofanalysis.utility as ut
+import tushare as ts
 
 
 class TSDataUpdate:
-    def __init__(self):
-        self.__pro = const.TS_PRO
+    def __init__(self, ts_pro_token:str):
+        self.__pro = ts.pro_api(ts_pro_token)
         self.__today = datetime.date.today()
 
     def retrieve_all(self):
